Container Module
================

The container module provides the main classes for working with molecules and their 
interaction profiles.

.. automodule:: shepherd_score.container
   :members:
   :undoc-members:
   :show-inheritance:
